pub struct UserSessionSubpage {
display_name: TemplateChild<EntryRow>,
display_name_button: TemplateChild<ActionButton>,
verified_status: TemplateChild<ActionRow>,
log_out_button: TemplateChild<ButtonRow>,
loading_disconnect_button: TemplateChild<LoadingButtonRow>,
open_url_disconnect_button: TemplateChild<ButtonRow>,
user_session: BoundObject<UserSession>,
account_settings: BoundConstructOnlyObject<AccountSettings>,
}Fields
display_name: TemplateChild<EntryRow>verified_status: TemplateChild<ActionRow>user_session: BoundObject<UserSession>The user session displayed by this subpage.
account_settings: BoundConstructOnlyObject<AccountSettings>The ancestor AccountSettings.
Implementations
Sourceimpl UserSessionSubpage
impl UserSessionSubpage
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl UserSessionSubpage
impl UserSessionSubpage
Sourcefn set_user_session(&self, user_session: UserSession)
fn set_user_session(&self, user_session: UserSession)
Set the user session displayed by this subpage.
Sourcefn update_verified(&self)
fn update_verified(&self)
Update the verified status.
Sourcefn set_account_settings(&self, account_settings: AccountSettings)
fn set_account_settings(&self, account_settings: AccountSettings)
Set the ancestor AccountSettings.
Sourcefn account_management_url_builder(&self) -> Option<AccountManagementUrlBuilder>
fn account_management_url_builder(&self) -> Option<AccountManagementUrlBuilder>
The builder for the account management URL of the OAuth 2.0 authorization server, if any.
Update the visible disconnect button.
Sourcefn display_name_changed(&self)
fn display_name_changed(&self)
Update the display name button when the display name is changed by the user.
Sourcefn has_display_name_changed(&self) -> bool
fn has_display_name_changed(&self) -> bool
Whether the display name in the entry row is different than the user session’s.
Sourceasync fn rename_user_session(&self)
async fn rename_user_session(&self)
Update the display name of the user session by making a request to the homeserver.
Sourceasync fn disconnect_with_request(&self)
async fn disconnect_with_request(&self)
Disconnect the user session by making a request to the homeserver.
async fn open_disconnect_url(&self)